==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco519CErrorHandling.cpp <==
/*!***************************************************************************

  module      : vco519CErrorHandling.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of co519CErrorHandling
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO519CERRORHANDLING_H
#include "gco519CErrorHandling.h"
#endif
#ifndef GCO51CSQLSESSIONCONTEXT_H
#include "gco51CSqlSessionContext.h"
#endif

/*
      e_unknown_error                =  -27000;
      e_inp_null_not_allowed         =  -27001;
      e_inp_number_invalid           =  -27002;
      e_inp_number_overflow          =  -27003;
      e_param_list_too_long          =  -27004;
      e_param_list_too_short         =  -27005;
      e_incompatible_datatype        =  -27006;
      e_too_many_hostvar             =  -27007;
      e_missing_variable_addr        =  -27008;
      e_cmd_too_long                 =  -27009;
      e_copyop_not_allowed           =  -27010;
      e_inp_string_truncated         =  -27011;
      e_use_callstm                  =  -27012;
      e_cmd_not_available            =  -27013;
*/

const char* co519CErrorHandling::m_error_msg[20] = {
  "unknown error " ,                                    /* e_unknown_error        */
  "input parameter cannot be null value" ,              /* e_inp_null_not_allowed */
  "invalid numeric input parameter value"  ,            /* e_inp_number_invalid   */
  "numeric input parameter overflow" ,                  /* e_inp_number_overflow  */
  "parameter list too long" ,                           /* e_param_list_too_long  */
  "parameter list too short" ,                          /* e_param_list_too_short */
  "incompatible data types" ,                           /* e_incompatible_datatype*/
  "too many host variables" ,                           /* e_too_many_hostvar     */
  "missing variable address" ,                          /* e_missing_variable_addr*/
  "command too long" ,                                  /* e_cmd_too_long         */
  "     " ,                                             /* e_copyop_not_allowed   */
  "input string truncated" ,                            /* e_inp_string_truncated */
  "   " ,                                               /* e_use_callstm          */
  "command not available" ,                             /* e_cmd_not_available    */
  "connect not ok" ,                                    /* e_dbconnect_notok      */
  "connection down" ,                                   /* e_dbconnection_down    */
  "db shutdown" ,                                       /* e_dbshutdown           */
  "too many users" ,                                    /* e_too_many_users       */
  "connection error" ,                                  /* e_notok                */
  "Unicode/ASCII convertion failed"                     /* e_uni_to_ascii_conv_failed PTS 1121444 2003-04-04 */
};

co519CErrorHandling::co519CErrorHandling() {
}


const char* co519CErrorHandling::getErrorDesc(tgg00_BasisError e) {
  int idx = abs(e) - 27000;
  if ( !(( idx >= 0 ) && ( idx <= 18 ))) idx = 0;  
  return m_error_msg[idx];
};

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco519CErrorHandling.cpp <==
/*!***************************************************************************

  module      : vco519CErrorHandling.cpp

  -------------------------------------------------------------------------

  responsible : FerdiF

  special area: C++ SQL Class   
  description : Implementation of co519CErrorHandling
				
  
  last changed: 2000-03-08  11:22
  see also    : 

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 2000



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#ifndef GCO519CERRORHANDLING_H
#include "gco519CErrorHandling.h"
#endif
#ifndef GCO51CSQLSESSIONCONTEXT_H
#include "gco51CSqlSessionContext.h"
#endif

/*
      e_unknown_error                =  -27000;
      e_inp_null_not_allowed         =  -27001;
      e_inp_number_invalid           =  -27002;
      e_inp_number_overflow          =  -27003;
      e_param_list_too_long          =  -27004;
      e_param_list_too_short         =  -27005;
      e_incompatible_datatype        =  -27006;
      e_too_many_hostvar             =  -27007;
      e_missing_variable_addr        =  -27008;
      e_cmd_too_long                 =  -27009;
      e_copyop_not_allowed           =  -27010;
      e_inp_string_truncated         =  -27011;
      e_use_callstm                  =  -27012;
      e_cmd_not_available            =  -27013;
      e_uni_to_ascii_conv_failed     =  -27019; ** PTS 1116580 2002-07-22
*/

const char* co519CErrorHandling::m_error_msg[SQLCLS_ErrCnt] = {
  "unknown error " ,                                    /* e_unknown_error        */
  "input parameter cannot be null value" ,              /* e_inp_null_not_allowed */
  "invalid numeric input parameter value"  ,            /* e_inp_number_invalid   */
  "numeric input parameter overflow" ,                  /* e_inp_number_overflow  */
  "parameter list too long" ,                           /* e_param_list_too_long  */
  "parameter list too short" ,                          /* e_param_list_too_short */
  "incompatible data types" ,                           /* e_incompatible_datatype*/
  "too many host variables" ,                           /* e_too_many_hostvar     */
  "missing variable address" ,                          /* e_missing_variable_addr*/
  "command too long" ,                                  /* e_cmd_too_long         */
  "     " ,                                             /* e_copyop_not_allowed   */
  "input string truncated" ,                            /* e_inp_string_truncated */
  "   " ,                                               /* e_use_callstm          */
  "command not available" ,                             /* e_cmd_not_available    */
  "connect not ok" ,                                    /* e_dbconnect_notok      */
  "connection down" ,                                   /* e_dbconnection_down    */
  "db shutdown" ,                                       /* e_dbshutdown           */
  "too many users" ,                                    /* e_too_many_users       */
  "connection error" ,                                  /* e_notok                */
  "Unicode/ASCII convertion failed" ,                   /* e_uni_to_ascii_conv_failed PTS 1116580 2002-07-22 */
  "NONASCII character in ASCII column"                  /* e_nonascii_char PTS 1121341 */
};

co519CErrorHandling::co519CErrorHandling() {
}


const char* co519CErrorHandling::getErrorDesc(tgg00_BasisError e) {
  int idx = abs(e) - 27000;
  if ( !(( idx >= 0 ) && ( idx <= SQLCLS_ErrCnt-1 ))) idx = 0;  
  return m_error_msg[idx];
};
